###############################################################################
# Orkid Build System
# Copyright 2010-2018, Michael T. Mayers
# email: michael@tweakoz.com
# The Orkid Build System is published under the GPL 2.0 license
# see http://www.gnu.org/licenses/gpl-2.0.html
###############################################################################

VERSION = "master"

import os, tarfile
from yarl import URL
from obt import dep, host, path, cmake, git, make
from obt.deco import Deco
from obt.wget import wget
from obt.command import Command

deco = Deco()

###############################################################################

class vrx(dep.Provider):

  def __init__(self): ############################################
    super().__init__("vrx")
    #print(options)
    self.source_root = path.builds()/"vrx"
    self.build_dest = path.builds()/"vrx"/".build"
    self.manifest = path.manifests()/"vrx"
    self.OK = self.manifest.exists()
    self._archlist = ["x86_64"]
  def __str__(self): ##########################################################

    return "VRX (github-%s)" % VERSION

  def build(self): ##########################################################

    assimp = dep.require("assimp")
    glfw = dep.require("glfw")
    utpp = dep.require("unittestpp")

    if self.should_incremental_build:
        os.chdir(self.build_dest)
    else:
        git.Clone("https://github.com/tweakoz/vrx",self.source_root,VERSION)
        os.system("rm -rf %s"%self.build_dest)
        os.mkdir(self.build_dest)
        os.chdir(self.build_dest)
        cmake_ctx = cmake.context("..")
        cmake_ctx.exec()

    rval = (make.exec("install")==0)
    return rval

  def linkenv(self): ##########################################################
    LIBS = ["obt.vrx"]
    return {
        "LIBS": LIBS,
        "LFLAGS": ["-l%s"%item for item in LIBS]
    }



###############################################################################
# Orkid Build System
# Copyright 2010-2020, Michael T. Mayers
# email: michael@tweakoz.com
# The Orkid Build System is published under the GPL 2.0 license
# see http://www.gnu.org/licenses/gpl-2.0.html
###############################################################################
from obt import dep, host, path, pathtools
###############################################################################
class igl(dep.StdProvider):
  name = "igl"
  def __init__(self):
    super().__init__(igl.name)
    #self._archlist = ["x86_64"]
    self.declareDep("cmake")
    #self.declareDep("lapack")
    self.declareDep("eigen")
    BOOST = self.declareDep("boost")
    cgal_path = path.libs()/"cmake"/"CGAL"
    eig3_path = path.stage()/"share"/"eigen3"/"cmake"
    embr_path = path.libs()/"cmake"/"embree-3.9.0"
    glfw_path = path.libs()/"cmake"/"glfw3"
    module_path = "%s:%s:%s:%s"%(
                   cgal_path,
                   eig3_path,
                   embr_path,
                   glfw_path)
    self._builder = self.createBuilder(dep.CMakeBuilder)
    self._builder.requires(["eigen","tbb"])
    self._builder.setCmVar("LIBIGL_WITH_CGAL","TRUE")
    self._builder.setCmVar("LIBIGL_USE_STATIC_LIBRARY","OFF")

    boost_cmake = BOOST.cmake_additional_flags()
    for key in boost_cmake.keys():
      val = boost_cmake[key]
      self._builder.setCmVar(key,val)

    #self._builder.setCmVar("CMAKE_MODULE_PATH",module_path)
    if host.IsOsx or host.IsAARCH64: # sadly mac igl-embree support is broken..
      # https://github.com/libigl/libigl/issues/1302
      self._builder.setCmVar("LIBIGL_WITH_EMBREE","OFF")
      self._builder.setCmVar("CMAKE_EXE_LINKER_FLAGS","-ld_classic")

    self._builder._parallelism = 0.5 # prevent out of memory..

    #####################################
    # install triangle
    #####################################

    def post_install():
      print("post installing IGL!!")
      igl_builddir = path.builds()/"igl"/".build"
      pathtools.copyfile(igl_builddir/"lib"/"libtriangle.a",path.libs()/"libtriangle.a")
      pathtools.copyfile(igl_builddir/"_deps"/"triangle-src"/"triangle.h",path.includes()/"triangle.h")

    self._builder._onPostInstall = post_install

    #####################################

  ########################################################################
  @property
  def github_repo(self):
    return "tweakoz/libigl"
  ########################################################################
  @property
  def revision(self):
    return "toz-v2.5.0"
  ########################################################################
  @property
  def _fetcher(self):
    return dep.GithubFetcher(name=igl.name,
                             repospec=self.github_repo,
                             revision=self.revision,
                             shallow=False,
                             recursive=False)

  ########################################################################

  def areRequiredSourceFilesPresent(self):
    return (self.source_root/"README.md").exists()

  def areRequiredBinaryFilesPresent(self):
    return (path.includes()/"igl"/"igl_inline.h").exists()



#!/usr/bin/env python3

###############################################################################
# Orkid Build System
# Copyright 2010-2022, Michael T. Mayers
# email: michael@tweakoz.com
# The Orkid Build System is published under the GPL 2.0 license
# see http://www.gnu.org/licenses/gpl-2.0.html
###############################################################################

import os, sys, pathlib, argparse, string

assert(os.environ["OBT_SUBSPACE"]=="host")

parser = argparse.ArgumentParser(description='obt.build dep information')
parser.add_argument('dependency', metavar='D', type=str, help='a dependency you want information on')

_args = vars(parser.parse_args())

if len(sys.argv)==1:
    print(parser.format_usage())
    sys.exit(1)

depname = _args["dependency"]

from obt import dep, path, pathtools
from obt.deco import Deco
deco = Deco()

instance = dep.instance(depname)

if instance==None:
   print("no available dependency %s for this host/target"%depname)
   sys.exit(1)

def print_item(key,val):
 dstr = deco.inf(depname)
 kstr = deco.key(key)
 vstr = deco.val(val)
 print("%s.%s = %s"%(dstr,kstr,vstr))

src_present = str(instance.areRequiredSourceFilesPresent())
if src_present=="None":
   src_present = "False"

bin_present = str(instance.areRequiredBinaryFilesPresent())
if bin_present=="None":
   bin_present = "False"

decl_deps = list()
for dep_name in instance._required_deps.keys():
  dep_inst = instance._required_deps[dep_name]
  decl_deps += [dep_name]

print_item("name",instance._name)
print_item("provider_path",instance._node.module_path)
print_item("has_shell",hasattr(instance,"on_build_shell"))
print_item("has_envinit",hasattr(instance,"env_init"))
print()
#############################################################
if hasattr(instance,"github_repo"):
   print_item("github_repo",instance.github_repo)
if hasattr(instance,"revision"):
   print_item("revision",instance.revision)
#############################################################
if hasattr(instance,"download_URL"):
   print_item("download_URL",instance.download_URL)
if hasattr(instance,"download_MD5"):
   print_item("download_MD5",instance.download_MD5)
#############################################################
print()
print_item("scope",instance.scopestr)
print_item("manifest present",instance.exists)
print_item("source present",src_present)
print_item("binaries present",bin_present)
print_item("architectures", "All" if (instance._archlist==None) else instance._archlist)
print_item("declared deps",decl_deps)
print()
#############################################################
print_item("source root",instance.source_root)
print_item("build_src",instance.build_src)
if instance.build_src.exists():
  print_item("build_src size: ","%0.2f (MiB)"%(pathtools.sizeOfDirectory(instance.build_src)/1048576.0))

print_item("build_dest",instance.build_dest)

if instance.build_dest.exists():
  print_item("build_dest size: ","%0.2f (MiB)"%(pathtools.sizeOfDirectory(instance.build_dest)/1048576.0))
#############################################################





###############################################################################
# Orkid Build System
# Copyright 2010-2018, Michael T. Mayers
# email: michael@tweakoz.com
# The Orkid Build System is published under the GPL 2.0 license
# see http://www.gnu.org/licenses/gpl-2.0.html
###############################################################################

import os, shutil
import obt.path
from pathlib import PosixPath
from obt.deco import Deco
from obt.command import run

deco = Deco()

###############################################################################
# Checkout and/or update to a specific branch
#  TODO - handle local changes and other exceptions correctly
###############################################################################

def checkout_update(dest_path,rev,origin="origin"):
    cwd = os.getcwd()
    OK = False
    try:
      os.chdir(dest_path)
      retc = run(["git","checkout",rev],do_log=True)
      retc = run(["git","pull",origin, rev],do_log=True)
      OK = (0 == retc)
    finally:
      os.chdir(cwd)
    return OK

###############################################################################

def Clone(url,
          dest,
          rev="master",
          recursive=False,
          cache=True,
          shallow=False):

  cwd = os.getcwd()
  rval = False
  retc = 0

  dest_path = PosixPath(dest)
  dest_name = dest_path.name
  cache_dest = obt.path.gitcache()/dest_name

  ##############################################################################

  def _checkoutrevandupdate():
    nonlocal cwd
    nonlocal retc
    nonlocal rev
    nonlocal dest_path
    nonlocal recursive
    OK = (0 == retc)
    #print("OK1<%s> retc<%s>"%(OK,retc))
    try:
      os.chdir(dest_path)
      if OK:
        retc = run(["git","checkout",rev],do_log=True)
        OK = (0 == retc)
        #print("OK2<%d>"%OK)
        if OK:
          if recursive:
            retc = run(["git","submodule","update","--init","--recursive"],do_log=True)
            OK = (0 == retc)
            #print("OK3<%d>"%OK)
    finally:
      os.chdir(cwd)
    return OK

  ##############################################################################
  if recursive and (cache==False):
  ##############################################################################

    print("Cloning1 (recursive) URL<%s> to dest<%s>"%(deco.path(url),deco.path(dest_path)))
    retc = run(["git",
                "clone",
                "-n",
                str(url),
                str(dest_path),
                "--recursive"])

    return _checkoutrevandupdate()

  ##############################################################################
  elif cache:
  ##############################################################################

    destpar = (dest_path/"..").resolve()
    print(destpar)
    if False==cache_dest.exists():
      print("Mirroring URL<%s> to dest<%s>"%(deco.path(url),deco.path(cache_dest)))
      retc = run(["git",
                  "clone",
                  str(url),
                  str(cache_dest),
                  "--mirror"])
    print("Cloning2 (from gitcache<%s>) to dest<%s> retc<%s>"%(deco.path(cache_dest),deco.path(dest),retc))
    if dest_path.exists():
      shutil.rmtree(str(dest_path))
    if 0 == retc:
      retc = run(["git",
                  "clone",
                  "--reference",
                  str(cache_dest),
                  str(url),
                  str(dest_path)])
      return _checkoutrevandupdate()

  ##############################################################################
  else:
  ##############################################################################

    print("Cloning3 URL<%s> to dest<%s>"%(deco.path(url),deco.path(dest_path)))
    print("shallow<%d>"%shallow)
    if shallow:
      # shallow clone of speciific rev
      if dest_path.exists():
        shutil.rmtree(str(dest_path))
      run(["mkdir","-p",dest_path])
      curdir = os.getcwd()
      os.chdir(dest_path)
      ####################
      retc = run(["git","init"],do_log=True)
      ####################
      if retc==0:
        retc = run(["git","remote","add","origin",url],do_log=True)
      ####################
      if retc==0:
        retc = run(["git","fetch","--depth","1","origin",rev],do_log=True)
      ####################
      if retc==0:
        retc = run(["git","checkout","FETCH_HEAD"],do_log=True)
      ####################
      if retc==0:
        munged_branch_name = rev
        if munged_branch_name.find("obt-")==-1:
           munged_branch_name = "obt-%s"%rev
        retc = run(["git","checkout","-b",munged_branch_name],do_log=True)
      ####################
      if retc==0:
        os.chdir(curdir)
      ####################
      if retc==0 and recursive:
         retc = run(["git","submodule","update","--init","--recursive"],do_log=True)
      ####################
      print(retc)
      return (0 == retc)
    else:
        retc = run(["git","clone",url,dest_path],do_log=True)
        if 0 == retc:
          return _checkoutrevandupdate()

  ##############################################################################
  return False



#!/usr/bin/env python3 

from obt import path, pathtools, macos, dep, deco, command
import os, argparse
deco = deco.Deco()

parser = argparse.ArgumentParser(description='obt.d build')
parser.add_argument('--alllibs', action="store_true", help='do all libs' )
parser.add_argument('--orklibs', action="store_true", help='do orkid libs' )
parser.add_argument('--orkpymods', action="store_true", help='do orkid python modules' )
parser.add_argument('--boost', action="store_true", help='do boost libs' )

_args = vars(parser.parse_args())


def do_boost():
  for mach_o_path in pathtools.patglob(path.stage()/"lib","libboost*.dylib"):
    dylib_paths = macos.macho_enumerate_dylibs(mach_o_path)
    for inpitem in dylib_paths:
      if(inpitem.find("libboost")==0):
        print(deco.yellow(inpitem))
        outitem = "@rpath/"+inpitem
        command.run(["install_name_tool","-change",inpitem,outitem,mach_o_path],do_log=True)
      else:
        print(inpitem)  

if _args["alllibs"]!=False:
  for item in pathtools.patglob(path.stage()/"lib","*.dylib"):
    macos.macho_replace_loadpaths(item,"@executable_path/../lib","@rpath")
    macos.macho_dump(item)
  do_boost()

if _args["orklibs"]!=False:
  for item in pathtools.patglob(path.stage()/"lib","libork*.dylib"):
    macos.macho_replace_loadpaths(item,"@executable_path/../lib","@rpath")
    macos.macho_dump(item)

if _args["orkpymods"]!=False:
  PYTHON = dep.instance("python")

  for item in pathtools.patglob(PYTHON.site_packages_dir/"orkengine"/"core","*.so"):
    macos.macho_replace_loadpaths(item,"@executable_path/../lib","@rpath")
    macos.macho_dump(item)

  for item in pathtools.patglob(PYTHON.site_packages_dir/"orkengine"/"lev2","*.so"):
    macos.macho_replace_loadpaths(item,"@executable_path/../lib","@rpath")
    macos.macho_dump(item)

if _args["boost"]!=False:
  do_boost()




#!/usr/bin/env python3

import obt.path
import obt.litex

arty_cmd = "./arty.py --output-dir %s"%(obt.path.builds()/"artysoc")

obt.litex.run( cpu="lm32",
               platform="arty",
               target="base",
               cmd=arty_cmd )



###############################################################################
# Orkid Build System
# Copyright 2010-2018, Michael T. Mayers
# email: michael@tweakoz.com
# The Orkid Build System is published under the GPL 2.0 license
# see http://www.gnu.org/licenses/gpl-2.0.html
###############################################################################

VERSION ="litex-vexriscv"

import os, tarfile
from obt import dep, host, path, git, cmake, make
from obt.deco import Deco
from obt.wget import wget
from obt.command import Command
from obt.cmake import context

deco = Deco()

###############################################################################

class zephyr(dep.Provider):

  def __init__(self): ############################################
    super().__init__("zephyr")
    self.source_root = path.builds()/"zephyr"
    self.build_dest = path.builds()/"zephyr"/".build"
    self.manifest = path.manifests()/"zephyr"
    self.OK = self.manifest.exists()
    self._archlist = ["x86_64"]
    self._oslist = ["Linux"]

  def __str__(self): ##########################################################

    return "ZEPHYR (github-tweakoz/litex-edition)"

  def env_goto(self): #########################################################
    return {
      "zephyr-src": self.source_root,
      "zephyr-build": self.build_dest
    }

  def build(self): ##########################################################

    git.Clone("https://github.com/tweakoz/zephyr",self.source_root,VERSION)

    os.system("rm -rf %s"%self.build_dest)
    os.mkdir(self.build_dest)
    os.chdir(self.build_dest)

    #cmake_ctx = cmake.context("..")
    #cmake_ctx.exec()
    #return (make.exec("install")==0)

    return True

  def provide(self): ##########################################################

    if self.should_build:

      self.OK = self.build()
      if self.OK:
        self.manifest.touch()

    print(self.OK)

    return self.OK



###############################################################################
# Orkid Build System
# Copyright 2010-2018, Michael T. Mayers
# email: michael@tweakoz.com
# The Orkid Build System is published under the GPL 2.0 license
# see http://www.gnu.org/licenses/gpl-2.0.html
###############################################################################

from pathlib import Path
import hashlib
import obt.path
from obt.command import Command
from obt import wget

###############################################################################
# caching download
###############################################################################

def scp( srcpath=None,
         output_name=None,
         md5val=None):

  assert(obt.path.downloads().exists())
  output_path = obt.path.downloads()/output_name
  hash_ok = False
  if md5val!=None:
    hash_ok = wget.check_hash(output_path,md5val)
    if hash_ok:
      return output_path

  if False==hash_ok:
    dl_succeeded = False
    res = Command(["scp",
                   "-C",
                   srcpath,
                   output_path
                   ]).exec()
    if res==0:
      dl_succeeded = True 
      if md5val != None:
        hash_ok = wget.check_hash(output_path,md5val)
        if False==hash_ok:
          return None
      return output_path

  return None




import os, atexit, json, sys
import socket

global log_node_stack  
global jsonroot

hostname = socket.gethostname()
jsonroot = list()
curwd = os.getcwd()
curpid = os.getpid()

topenv = dict(os.environ)


log_node_stack = list()
log_node_stack.append(jsonroot)

def stage_dir():
  if "OBT_STAGE" in os.environ.keys():
	  return os.environ["OBT_STAGE"]
  else:
    return None


FORBIDDEN_KEYS = ["SESSION_MANAGER","SSH_AUTH_SOCK","DESKTOP_SESSION","SSH_AGENT_PID","XDG_SESSION_DESKTOP"]
FORBIDDEN_KEYS += ["XDG_SESSION_TYPE","GPG_AGENT_INFO","VTE_VERSION","GNOME_TERMINAL_SCREEN"]
FORBIDDEN_KEYS += ["INVOCATION_ID","MANAGERPID","GNOME_TERMINAL_SERVICE","JOURNAL_STREAM"]
FORBIDDEN_KEYS += ["SDKMAN_VERSION","XDG_MENU_PREFIX","SBT_HOME","JAVA_HOME","XDG_CURRENT_DESKTOP"]
FORBIDDEN_KEYS += ["SDKMAN_CANDIDATES_API","SDKMAN_CANDIDATES_DIR","GDMSESSION"]
FORBIDDEN_KEYS += ["SDKMAN_PLATFORM","DBUS_SESSION_BUS_ADDRESS","XDG_RUNTIME_DIR","XDG_DATA_DIRS"]
FORBIDDEN_KEYS += ["XDG_CONFIG_DIRS","XDG_MENU_PREFIX","GNOME_DESKTOP_SESSION_ID","MANDATORY_PATH","GTK_MODULES"]
FORBIDDEN_KEYS += ["XDG_SESSION_CLASS","DEFAULTS_PATH","LESSOPEN","LESSCLOSE","TERM","DISPLAY","XMODIFIERS","XAUTHORITY"]
FORBIDDEN_KEYS += ["USER","HOME", "SDKMAN_DIR","SHELL","COLORTERM","EDITOR","GJS_DEBUG_TOPICS","GJS_DEBUG_OUTPUT","WINDOWPATH"]

################################################
# attempt to cleanse private info out of strings
################################################

def cleanseString(the_string):
  stage_as_str = stage_dir()
  home_as_str = str(os.environ["HOME"])
  user_as_str = str(os.environ["USER"])
  uid = os.getuid()
  usrrundir_as_str = "/run/user/%d"%uid
  ########################
  found = the_string.find(stage_as_str)
  if found >= 0:
    the_string = the_string.replace(stage_as_str,"${OBT_STAGE}")
  ########################
  found = the_string.find(home_as_str)
  if found >= 0:
    the_string = the_string.replace(home_as_str,"${HOME}")
  ########################
  if( "ORKID_WORKSPACE_DIR" in os.environ.keys() ):
    owsr_as_str = str(os.environ["ORKID_WORKSPACE_DIR"])
    found = the_string.find(owsr_as_str)
    if found >= 0:
      the_string = the_string.replace(owsr_as_str,"${OWSDIR}")
  ########################
  found = the_string.find(usrrundir_as_str)
  if found >= 0:
    the_string = the_string.replace(usrrundir_as_str,"${USERRUNDIR}")
  ########################
  found = the_string.find(user_as_str)
  if found >= 0:
    the_string = the_string.replace(user_as_str,"${USER}")
  ########################
  found = the_string.find(curwd)
  if found >= 0:
    the_string = the_string.replace(curwd,"${TOPEXECDIR}")
  ########################
  found = the_string.find(hostname)
  if found >= 0:
    the_string = the_string.replace(hostname,"${HOSTNAME}")
  return the_string

################################################

def iterlist(the_list):
  newl = list()
  for v in the_list:
    if isinstance(v,str):
      v = cleanseString(v)
    else:
      v = str(v)
      v = cleanseString(v)
    newl.append(v)
  return newl

################################################

def iterdict(the_dict,pard=None,park=None):
 ####################################
 def _iterlist(the_list):
  newl = list()
  for v in the_list:
   if isinstance(v, dict):
    v = iterdict(v,pard,park)
   elif isinstance(v, list):
    v = _iterlist(v)
   elif isinstance(v,str):
     v = cleanseString(v)
   else:
     v = str(v)
     v = cleanseString(v)
   newl.append(v)
  return newl
 ####################################
 newd = dict()
 ####################################
 for k, v in the_dict.items():
  add = True
  if isinstance(v, dict):
    v = iterdict(v,the_dict,k)
  elif isinstance(v, list):
    v = _iterlist(v)
  else:
    if type(v) != str:
      v = str(v)
    v = cleanseString(v)
    if pard!=None and park!=None:
      if park=="os_env":
        if k in topenv:
          add = (v != cleanseString(str(topenv[k])))
          #print("match<k:%s> <v:%s> <te:%s> : %d"%(k,v,topenv[k], int(add)))
  if k in FORBIDDEN_KEYS:
  	add = False
  if add:
    newd[k] = v
 return newd  

################################################

def buildTrace(item):
  index = len(log_node_stack)-1
  top = log_node_stack[index]
  top.append(item)

################################################

class NestedBuildTrace(object):
  def __init__(self, item):
    self._item = item

  def __enter__(self):
    index = len(log_node_stack)-1
    top = log_node_stack[index]
    top.append(self._item)
    subops = list()
    self._item["subops"] = subops
    log_node_stack.append(subops)
    return self

  def __exit__(self, etype, value, traceback):
    log_node_stack.pop()


################################################

def proc_list(the_list):
  newlist = list()
  for item in the_list:
   newlist.append(iterdict(item))
  return newlist 

################################################

def savelog():
  import obt._globals as _glob
  if _glob.isBuildTraceEnabled():
    steplogfile = "%s/buildlogs/obtdump-%d.json"%(stage_dir(),curpid)
    copy = list(jsonroot)
    processed = list()
    ##############################
    # write top level environment to log file
    ##############################
    processed += [{ "topenv": iterdict(topenv) }]
    processed += [{ "sysargv": iterlist(sys.argv) }]
    ##############################
    # process dictionary before logging
    ##############################
    processed += proc_list(copy)
    ##############################
    # write it out
    ##############################
    with open(str(steplogfile),"w") as f:
      as_str = json.dumps(processed, indent=2)
      f.write(as_str)

atexit.register(savelog)



from obt import template, path

class Generator:

  def __init__(self):
    self.template_str = ""

  def try_add_item(self,varname,key):
    if key in self.replacements.keys():
      val = self.replacements[key]
      if val != "":
        print(key,val,varname)
        self.template_str += "%s: %s\n" % (varname,str(val))

  def apply(self,replacements,outpath=None):
    self.replacements = replacements
    self.try_add_item("prefix","PREFIX")
    self.try_add_item("exec_prefix","PREFIX")
    self.try_add_item("includedir","PREFIX/include")
    self.try_add_item("Name","NAME")
    self.try_add_item("Description","DESCRIPTION")
    self.try_add_item("Requires","REQUIRES")
    self.try_add_item("Version","VERSION")
    self.try_add_item("Libs.private","LIBS_PRIVATE")
    self.try_add_item("Libs","LIBS_PUBLIC")
    self.try_add_item("Cflags","CFLAGS")

    #print(self.template_str,replacements)
    #out = template.template_string(self.template_str,replacements)
    #print( "#################################")
    #print(self.template_str)
    #print( "#################################")

    if outpath!=None:
      with open(str(outpath),"w") as outfile:
        outfile.write(self.template_str)

    return self.template_str


from setuptools import setup, find_packages
import glob, os
import platform

version = "0.0.127"

###############################################################################

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

###############################################################################

def package_files(directory):
  data_files = []
  for root, dirs, files in os.walk(directory):
    for filename in files:
      if not (filename.endswith('.pyc') or '.egg-info' in root or '__pycache__' in root):
        filepath = os.path.join(root, filename)
        dest_dir = os.path.join('obt', root)
        data_files.append((dest_dir, [filepath]))
  return data_files

###############################################################################

module_files = package_files('modules')
example_files = package_files('examples')
test_files = package_files('tests')
binpriv_files = package_files('bin_priv')
binpub_files = [f[1][0] for f in package_files("bin_pub")]

###############################################################################
data_files = module_files + example_files + test_files + binpriv_files
###############################################################################

setup(
    name="ork.build",
    version=version,
    author="Michael T. Mayers",
    author_email="michael@tweakoz.com",
    description="Orkid Build Tools",
    long_description=long_description,
    long_description_content_type='text/markdown',
    url="https://github.com/tweakoz/ork.build",
    packages=find_packages(where="scripts"),
    package_dir={
        "": "scripts",
    },
    data_files=data_files,
    scripts=binpub_files,
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
    install_requires=[
        'yarl',
        'toposort',
        'os-release',
        'distro'
    ],
    )



#!/usr/bin/env python3
###############################################################################
import sys
from obt import host, path
from obt.command import capture
from obt.command import Deco
deco = Deco()
###############################################################################
def find_replace(inpstring, dictionary):
  print(dictionary)
  for item in inpstring:
    if item in dictionary.keys():
      print("replacing item<%s>"%item)
      inpstring = inpstring.replace(item, dictionary[item])
  return inpstring

###############################################################################
def macho_enumerate_dylibs(mach_o_path):
  assert (host.IsOsx)
  loadlines = capture(["otool","-l",mach_o_path],do_log=False).splitlines()
  cmdindex = 0
  cmd = None
  name = None
  state = 0
  dylib_paths = list()
  for line in loadlines:
    tokens = line.split(" ")
    tokens = [i for i in tokens if i]
    if state==0:
      if tokens[0]=="Load" and tokens[1]=="command":
        cmdindex = int(tokens[2])
        state = 1
    elif state==1:
      if tokens[0]=="cmd" and tokens[1]=="LC_LOAD_DYLIB":
        cmd = "LC_LOAD_DYLIB"
        state = 2
    elif state==2:
      if tokens[0] == "name":
        dylib_paths += [tokens[1]]
        state=0
    else:
      assert(False)
  return dylib_paths
###############################################################################
def macho_replace_loadpaths(mach_o_path,search,replace):
  assert (host.IsOsx)
  str_search = str(search)
  str_replace = str(replace)
  dylib_paths = macho_enumerate_dylibs(mach_o_path)
  for inpitem in dylib_paths:
    outitem = inpitem.replace(str_search, str_replace)
    #print("mach_o_path: " + str(mach_o_path) + " inp: " + inpitem + " search: " + str_search + " replace: " + str_replace)
    if outitem!=inpitem:
      capture(["install_name_tool","-change",inpitem,outitem,mach_o_path],do_log=False)
###############################################################################
def macho_change_id(mach_o_path,id_str):
  assert (host.IsOsx)
  capture(["install_name_tool","-id",'%s'%id_str,mach_o_path],do_log=False)
###############################################################################
def macho_get_id(mach_o_path):
  assert (host.IsOsx)
  return capture(["otool","-D",mach_o_path],do_log=False)
##############################################################################
def macho_dump(mach_o_path):
  print(deco.val("/////////////////////////////////////////////////////////"))
  print(deco.val("MachO Dump: ") + deco.val(mach_o_path))
  print(deco.val("/////////////////////////////////////////////////////////"))
  dylib_paths = macho_enumerate_dylibs(mach_o_path)
  for item in dylib_paths:
    print(deco.val("dylib: ")+deco.path(item))
  print(deco.val("/////////////////////////////////////////////////////////"))
